#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TWELVE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TWELVE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/twelve.hpp>

#endif
